---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons

---------------------------
-- create the button
---------------------------
gf.AddButton("Armor","LEFT")
local btn = gb.Armor
btn.text			  = "Armor"
btn.enabled		   = true
btn.events			= {"MERCHANT_SHOW","UNIT_DAMAGE","UPDATE_INVENTORY_DURABILITY"}
btn.update			= true
btn.tooltip		   = true
btn.menu			  = true
btn.save.perCharacter = {["autoRepair"] = true,["guildRepair"] = true}
btn.save.allowProfile = true
local spc = btn.save.perCharacter

---------------------------
-- variables
---------------------------
ga.slotItems = {
	"HEADSLOT",
	"SHOULDERSLOT",
	"CHESTSLOT",
	"WRISTSLOT",
	"HANDSSLOT",
	"WAISTSLOT",
	"LEGSSLOT",
	"FEETSLOT",
	"MAINHANDSLOT",
	"SECONDARYHANDSLOT",
	"BACKSLOT",
	"FINGER0SLOT",
	"FINGER1SLOT",
	"NECKSLOT",
	"TRINKET0SLOT",
	"TRINKET1SLOT",
}
gv.party.a["Armor"] = 0
gv.party.b["Armor"] = 0
gv.party.c["Armor"] = 0
gv.party.d["Armor"] = 0

---------------------------
-- special handling
---------------------------
CreateFrame("GameTooltip","Glance_Tooltip_Armor",UIParent,"GameTooltipTemplate")

---------------------------
-- update
---------------------------
function gf.Armor.update(self, event, arg1)
	local btn = gb.Armor
	if btn.enabled and gv.loaded then -- loaded keeps it from launching when defined
		Glance.Debug("function","update","Armor")
		btn.button:SetText("Armor: ".. gf.Armor.GetDurability().."%")
		btn.button:SetWidth(btn.button:GetTextWidth())
		if event == "MERCHANT_SHOW" then
			gf.Armor.repair()
		end
	end
end

---------------------------
-- tooltip
---------------------------
function gf.Armor.tooltip()
	Glance.Debug("function","tooltip","Armor")
	local tooltip = gf.Tooltip
	tooltip.Title("Armor", "GLD")
	local TotalRepairCost = gf.Armor.checkInventory()
	if TotalRepairCost > 0 then
		tooltip.Line("The total cost to repair your armor is: "..GetCoinTextureString(TotalRepairCost,0), "WHT")
	else
		tooltip.Line("Your armor is fully repaired.", "WHT")
	end
	tooltip.Space()
	tooltip.Line("Item Level (iLvl)", "GLD")
	local itemLevel, eItemLevel = GetAverageItemLevel()
	tooltip.Double("Average Item Level",gf.Armor.level(math.floor(itemLevel)), "WHT", "WHT")
	tooltip.Double("Equipped Item Level",gf.Armor.level(math.floor(eItemLevel)), "WHT", "WHT")
	local GetNumPartyMembers, _ = GetNumSubgroupMembers()
	if ((GetNumPartyMembers ~= 0 and sender ~= UnitName("player")) or gv.Debug) and Glance_Local.Options.sendStats then
		gf.addonQuery("Armor")
		local pty = gv.party
		tooltip.Space()
		tooltip.Double("Party", "(eLVL/iLVL)/DUR", "GLD", "GLD")
		if pty.a.Armor ~= 0 then
			tooltip.Double(pty.a.name, pty.a.Armor, "WHT", "GRN")
		end
		if pty.b.Armor ~= 0 then
			tooltip.Double(pty.a.name, pty.b.Armor, "WHT", "GRN")
		end
		if pty.c.Armor ~= 0 then
			tooltip.Double(pty.a.name, pty.c.Armor, "WHT", "GRN")
		end
		if pty.d.Armor ~= 0 then
			tooltip.Double(pty.a.name, pty.d.Armor, "WHT", "GRN")
		end
	end
	tooltip.Space()
	tooltip.Line("Options", "GLD")
	if spc.autoRepair then
		tooltip.Double("Auto-Repair", "On", "WHT", "GRN")
	else
		tooltip.Double("Auto-Repair", "Off", "WHT", "RED")
	end
	if spc.guildRepair then
		if CanGuildBankRepair() then
			tooltip.Double("Use Guild Funds", "On", "WHT", "GRN")
		else
			tooltip.Double("Use Guild Funds", "On", "WHT", "GRY")
		end
	else
		tooltip.Double("Use Guild Funds", "Off", "WHT", "RED")
	end
	if CanGuildBankRepair() then
		local GuildMoney = GetGuildBankWithdrawMoney()
		if GuildMoney == -1 then 
			tooltip.Double("Guild funds available today", "Unlimited", "WHT", "WHT")
		else
			tooltip.Double("Guild funds available today", GetCoinTextureString(math.ceil(GuildMoney),0), "WHT", "WHT")
		end
	end
	tooltip.Space()
	tooltip.Line("(Right-Click to change Options)", "WHT")
end

---------------------------
-- menu
---------------------------
function gf.Armor.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Armor")
	local HEX = ga.colors.HEX
	level = level or 1
	if (level == 1) then
		gf.setInfo(nil,true,false,true,nil,HEX.white.."Armor Options","spacer",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Auto Repair","autorepair",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Use Guild Funds","guildrepair",level,nil)
	end
	if (level == 2) then
		if UIDROPDOWNMENU_MENU_VALUE == "autorepair" then
			local checked, func
			if spc.autoRepair then checked = true else checked = false end
			func = function() spc.autoRepair=true; end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			gf.setInfo(nil,false,false,false,checked,"On","On",level,func)
			if spc.autoRepair then checked = false else checked = true end
			func = function() spc.autoRepair=false; end;
			gf.setInfo(nil,false,false,false,checked,"Off","Off",level,func)
		end
		if UIDROPDOWNMENU_MENU_VALUE == "guildrepair" then
			local checked, func
			if spc.guildRepair then checked = true else checked = false end
			func = function() spc.guildRepair=true; end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			gf.setInfo(nil,false,false,false,checked,"On","On",level,func)
			if spc.guildRepair then checked = false else checked = true end
			func = function() spc.guildRepair=false; end;
			gf.setInfo(nil,false,false,false,checked,"Off","Off",level,func)
		end
	end
end

---------------------------
-- messaging
---------------------------
function gf.Armor.Message()
	local itemLevel, eItemLevel = GetAverageItemLevel()
	local eItemLevel = 0
	return "|r("..gf.Armor.level(math.floor(eItemLevel)).."|r/"..gf.Armor.level(math.floor(itemLevel)).."|r)/"..gf.Armor.GetDurability().."%"
end

---------------------------
-- durability 
---------------------------
function gf.Armor.GetDurability()
	local HEX = ga.colors.HEX
	local have, most, pct = 0,0,0
	local sOut
	for i = 1, 19 do
		local current, max = GetInventoryItemDurability(i)
		if current ~= nil then
			have = have + current
			most = most + max
		end
	end
	pct = math.floor((have/most) * 100)
	if pct >= 75 then
		sOut = HEX.green..pct
	elseif pct < 75 and pct > 50 then
		sOut = HEX.yellow..pct
	else
		sOut = HEX.red..pct
	end
	return sOut
end

---------------------------
-- repair costs
---------------------------
function gf.Armor.checkInventory()
	local TotalRepairCost = 0
	for i=1, #ga.slotItems do
		local slotId, textureName = GetInventorySlotInfo(ga.slotItems[i])
		local hasItem, hasCooldown, repairCost = Glance_Tooltip_Armor:SetInventoryItem("player", slotId);
		if hasItem then
			TotalRepairCost = TotalRepairCost + (repairCost or 0)
		end
	end
	Glance_Tooltip_Armor:Hide()
	return TotalRepairCost
end

---------------------------
-- armor repair
---------------------------
function gf.Armor.repair()
	Glance.Debug("function","repair","Armor")
	if CanMerchantRepair()==1 and spc.autoRepair then
		local cost, needed = GetRepairAllCost();
		if needed then
			if CanGuildBankRepair() and spc.guildRepair then
				local funds = GetGuildBankWithdrawMoney()
				if cost > funds then
					local funds = GetMoney()
					if cost > funds then
						gf.sendMSG("You don't have enough money for repair!");
					else
						RepairAllItems();
						gf.sendMSG("There was not enough money in your daily guild bank allotment for repair.  Your items have been repaired from your own funds for "..GetCoinTextureString(cost,0))
					end
				else
					RepairAllItems(1)
					gf.sendMSG("Your items have been repaired by the guild for "..GetCoinTextureString(cost,0))
					return
				end
			else
				local funds = GetMoney()
				if cost > funds then
					gf.sendMSG("You don't have enough money for repair!");
				else
					RepairAllItems();
					gf.sendMSG("Your items have been repaired for "..GetCoinTextureString(cost,0))
				end
			end
		end
	end
end

---------------------------
-- item level
---------------------------
function gf.Armor.level(itemLevel)
	local HEX = ga.colors.HEX
	if itemLevel < 272 then
		return HEX.gray..itemLevel
	elseif itemLevel < 305 then
		return HEX.white..itemLevel
	elseif itemLevel < 329 then
		return HEX.green..itemLevel
	elseif itemLevel < 346 then
		return HEX.blue..itemLevel
	elseif itemLevel >= 346 then
		return HEX.purple..itemLevel
	end
end

---------------------------
-- get item level
---------------------------
function gf.Armor.GetItemLevel(slot)
	if GetInventoryItemID("Player", GetInventorySlotInfo(slot)) ~= nil then
		local _, _, _, iLevel = GetItemInfo(GetInventoryItemID("Player", GetInventorySlotInfo(slot)));
		return iLevel;
	else 
		return 0;
	end
end

---------------------------
-- load on demand
---------------------------
if gv.loaded then
	gf.Enable("Armor")
end