---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons

---------------------------
-- create the button
---------------------------
gf.AddButton("Pets","RIGHT")
local btn = gb.Pets
btn.text              = "      "
btn.enabled           = true
btn.texture.normal    = "Interface\\AddOns\\Glance_Pets\\paw.tga"
btn.events            = {"COMPANION_LEARNED","PET_JOURNAL_AUTO_SLOTTED_PET","PET_JOURNAL_LIST_UPDATE","PET_JOURNAL_PET_DELETED"}
btn.update            = true
btn.click             = true
btn.tooltip           = true
btn.menu              = true
btn.options           = true
btn.onload            = true
btn.save.perAccount   = {["Pets"] = {}}
local spa = btn.save.perAccount

---------------------------
-- variables
---------------------------
ga.pet = {}
ga.alphabet = {
	["a"] = "ae",
	["b"] = "ae",
	["c"] = "ae",
	["d"] = "ae",
	["e"] = "ae",
	["f"] = "fj",
	["g"] = "fj",
	["h"] = "fj",
	["i"] = "fj",
	["j"] = "fj",
	["k"] = "ko",
	["l"] = "ko",
	["m"] = "ko",
	["n"] = "ko",
	["o"] = "ko",
	["p"] = "pt",
	["q"] = "pt",
	["r"] = "pt",
	["s"] = "pt",
	["t"] = "pt",
	["u"] = "uz",
	["v"] = "uz",
	["w"] = "uz",
	["x"] = "uz",
	["y"] = "uz",
	["z"] = "uz",
}
gv.PetScrollIDX = 0
gv.PetPanelIDX = 0
gv.PetCount = 0

---------------------------
-- update
---------------------------
function gf.Pets.update(self, event, arg1)
	if event == "COMPANION_LEARNED" then
		gf.Pets.resetPetList()
		gf.createMenu("Pets")
	end
end


---------------------------
-- tooltip
---------------------------
function gf.Pets.tooltip()
	Glance.Debug("function","tooltip","Pets")
	local tooltip = gf.Tooltip
	local HEX = ga.colors.HEX
	tooltip.Title("Pets", "GLD")
	tooltip.Line("You have obtained "..HEX.green..gv.PetCount..HEX.white.." companion pets.","WHT")
	tooltip.Space()
	tooltip.Wrap("(Click to open the Pet tab.)","WHT")
	tooltip.Wrap("(Right-Click to show a dropdown menu of available companion pets for you to select and summon.)","WHT")
end


---------------------------
-- click
---------------------------
function gf.Pets.click(self, button, down)
	Glance.Debug("function","click","Pets")
	if button == "LeftButton" then
		TogglePetJournal(2) --SummonRandomCritter()
	end
end


---------------------------
-- onload
---------------------------
function gf.Pets.onload()
	gf.Pets.resetPetList()
end


---------------------------
-- menu
---------------------------
function gf.Pets.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Pets")
	local HEX = ga.colors.HEX
	level = level or 1
	if (level == 1) then
		gf.setInfo(nil,true,false,true,nil,HEX.white.."Pets Options","spacer",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Favorites","favorites",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Pets A-E","ae",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Pets F-J","fj",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Pets K-O","ko",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Pets P-T","pt",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Pets U-Z","uz",level,nil)
		local func = function() DismissCompanion("CRITTER") end;
		gf.setInfo(nil,nil,nil,true,nil,HEX.red.."Dismiss Pet","dis",level,func)
	end
	if (level == 2) then
		for i=1,#ga.pet do
			local id, creatureName, icon, issummoned, enabled, favorite, lvl = unpack(ga.pet[i])
			if ga.alphabet[strlower(string.sub(creatureName,1,1))] == UIDROPDOWNMENU_MENU_VALUE and enabled then
				local checked, func
				checked = (C_PetJournal.GetSummonedPetID() == i)
				func = function() gf.Pets.summon(i); end;
				gf.setInfo(nil,false,false,false,checked,creatureName.." ("..lvl..")",name,level,func,icon)
			end
			if UIDROPDOWNMENU_MENU_VALUE == "favorites" and enabled and favorite then
				local checked, func
				checked = (C_PetJournal.GetSummonedPetID() == i)
				func = function() gf.Pets.summon(i); end;
				gf.setInfo(nil,false,false,false,checked,creatureName.." ("..lvl..")",name,level,func,icon)
			end
		end
	end
end

---------------------------
-- options
---------------------------
function gf.Pets.options()
	local pIDX = gf.createPanel("Pets","Select which companion pets you wish to be visible on the pets menu.",function(self) gv.overflowFix = true end)
	gv.PetScrollIDX = gf.createScrollBar(_G["Glance_Panel"..pIDX],18,-70,345,378,20,ga.pet,2,5,gf.Pets.setPreferredPet)
end

---------------------------
-- pet scrollbar click
---------------------------
function gf.Pets.setPreferredPet(line)
	local pref, name
	name = _G[getglobal("Glance_SBE"..gv.PetScrollIDX..line):GetName().."Text"]:GetText()
	pref = _G["Glance_SBE"..gv.PetScrollIDX..line]:GetChecked()
	if pref == 1 then
		pref = true
	else
		pref = false
	end
	if name ~= nil then
		spa.Pets[name] = pref
	end
	gf.Pets.resetPetList()
end

---------------------------
-- is summoned
---------------------------
function gf.Pets.isSummoned(id)
	if C_PetJournal.GetSummonedPetID() == id then
		return true
	else
		return false
	end
end

---------------------------
-- summon
---------------------------
function gf.Pets.summon(id)
	local creatureID, creatureName, creatureSpellID, icon, issummoned = GetCompanionInfo("CRITTER", id);
	if issummoned then
		DismissCompanion("CRITTER")
	else
		local _,myPets = C_PetJournal.GetNumPets(false)
		for i=1,myPets do
			local petID, speciesID, isOwned, customName, level, favorite, isRevoked, name, icon, petType, creatureID, sourceText, description, isWildPet, canBattle, tradable, unique = C_PetJournal.GetPetInfoByIndex(i, false)
			if name:lower() == creatureName:lower() then
				C_PetJournal.SummonPetByID(petID)
			end
		end
	end

end

---------------------------
-- get pet info
---------------------------
function gf.Pets.petInfo(id)
	local petID, speciesID, isOwned, customName, level, favorite, isRevoked, name, icon, petType, creatureID, sourceText, description, isWildPet, canBattle, tradable, unique = C_PetJournal.GetPetInfoByIndex(id, false)
	if C_PetJournal.GetSummonedPetID() == id then
		issummoned = true
	else
		issummoned = false
	end
	local showPet = true
	if spa.Pets[name] ~= nil then
		showPet = spa.Pets[name]
	end
	return petID, name, icon, issummoned, showPet, favorite, level
end

---------------------------
-- store pets in {}
---------------------------
function gf.Pets.resetPetList()
	Glance.Debug("function","resetPetList",nil)
	wipe(ga.pet)
	local petListChanged = false
    C_PetJournal.SetFlagFilter(LE_PET_JOURNAL_FLAG_COLLECTED, true) -- displays pets we do have
    C_PetJournal.SetFlagFilter(LE_PET_JOURNAL_FLAG_NOT_COLLECTED, false) -- ignores pets we don't have
	gv.PetCount = C_PetJournal.GetNumPets(false)
	for i=1,gv.PetCount do
		ga.pet[i] = { gf.Pets.petInfo(i) }
		if spa.Pets[ga.pet[i][2]] == nil then
			spa.Pets[ga.pet[i][2]] = true
			petListChanged = true
		end
	end
	if petListChanged then gf.sendMSG("Your pet list has changed.") end
end

---------------------------
-- load on demand
---------------------------
if gv.loaded then
	gf.Enable("Pets")
end