---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons

---------------------------
-- create the button
---------------------------
gf.AddButton("Pets","RIGHT")
local btn = gb.Pets
btn.text              = "      "
btn.enabled           = true
btn.texture.normal    = "Interface\\AddOns\\Glance_Pets\\paw.tga"
btn.events            = {"COMPANION_LEARNED","PET_JOURNAL_AUTO_SLOTTED_PET","PET_JOURNAL_LIST_UPDATE","PET_JOURNAL_PET_DELETED"}
btn.update            = true
btn.click             = true
btn.tooltip           = true
btn.menu              = true
btn.options           = true
btn.onload            = true
btn.save.perAccount   = {["Pets"] = {}}
local spa = btn.save.perAccount

---------------------------
-- variables
---------------------------
ga.pet = {}
gv.PetScrollIDX = 0
gv.PetPanelIDX = 0
gv.PetCount = 0

---------------------------
-- update
---------------------------
function gf.Pets.update(self, event, arg1)
	if event == "COMPANION_LEARNED" then
		gf.Pets.resetPetList()
		gf.createMenu("Pets")
	end
end


---------------------------
-- tooltip
---------------------------
function gf.Pets.tooltip()
	Glance.Debug("function","tooltip","Pets")
	local tooltip = gf.Tooltip
	local HEX = ga.colors.HEX
	if gv.PetCount ~= C_PetJournal.GetNumPets(false) then
		gf.Pets.resetPetList()
		gf.createMenu("Pets")
	end
	tooltip.Title("Pets", "GLD")
	tooltip.Wrap("You have obtained "..HEX.green..gv.PetCount..HEX.white.." companion pets. This list is controlled by the filters in your Pet journal. Pets that can not battle will be shown in "..HEX.red.."red.","WHT")
	tooltip.Space()
	tooltip.Wrap("(Click to summon a random pet.)","WHT")
	tooltip.Wrap("(Right-Click to show a dropdown menu of available companion pets for you to select and summon.)","WHT")
end


---------------------------
-- click
---------------------------
function gf.Pets.click(self, button, down)
	Glance.Debug("function","click","Pets")
	if button == "LeftButton" then
		--TogglePetJournal(2) --SummonRandomCritter()
		C_PetJournal.SummonRandomPet(true);
	end
end


---------------------------
-- onload
---------------------------
function gf.Pets.onload()
	gf.Pets.resetPetList()
end


---------------------------
-- menu
---------------------------
function gf.Pets.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Pets")
	local HEX = ga.colors.HEX
	level = level or 1
	if (level == 1) then
		gf.setInfo(nil,true,false,true,nil,HEX.white.."Pets Options","spacer",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Favorites","favorites",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Aquatic","Aquatic",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Beast","Beast",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Critter","Critter",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Dragonkin","Dragonkin",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Elemental","Elemental",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Flying","Flying",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Humanoid","Humanoid",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Magic","Magic",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Mechanical","Mechanical",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Undead","Undead",level,nil)
		local func = function() DismissCompanion("CRITTER") end;
		gf.setInfo(nil,nil,nil,true,nil,HEX.red.."Dismiss Pet","dis",level,func)
	end
	if (level == 2) then
		for i=1,#ga.pet do
			local id, creatureName, icon, issummoned, enabled, favorite, lvl, petID, petType, canBattle = unpack(ga.pet[i])
			if _G["BATTLE_PET_NAME_"..petType] == UIDROPDOWNMENU_MENU_VALUE and enabled then
				local checked, func
				checked = (C_PetJournal.GetSummonedPetGUID() == petID)
				func = function() gf.Pets.summon(id); end;
				if(canBattle) then
					if(favorite) then
						gf.setInfo(nil,false,false,false,checked,HEX.lightblue..creatureName..HEX.gold.." ("..lvl..")",name,level,func,icon)
					else
						gf.setInfo(nil,false,false,false,checked,creatureName..HEX.gold.." ("..lvl..")",name,level,func,icon)
					end
				else
					gf.setInfo(nil,false,false,false,checked,HEX.red..creatureName..HEX.gold.." ("..lvl..")",name,level,func,icon)
				end
			end
			if UIDROPDOWNMENU_MENU_VALUE == "favorites" and enabled and favorite then
				local checked, func
				checked = (C_PetJournal.GetSummonedPetGUID() == petID)
				func = function() gf.Pets.summon(id); end;
				gf.setInfo(nil,false,false,false,checked,HEX.lightblue..creatureName..HEX.gold.." ("..lvl..")",name,level,func,icon)
			end
		end
	end
end

---------------------------
-- options
---------------------------
function gf.Pets.options()
	local pIDX = gf.createPanel("Pets","Select which companion pets you wish to be visible on the pets menu.",function(self) gv.overflowFix = true end)
	gv.PetScrollIDX = gf.createScrollBar(_G["Glance_Panel"..pIDX],18,-70,345,378,20,ga.pet,2,5,gf.Pets.setPreferredPet)
end

---------------------------
-- pet scrollbar click
---------------------------
function gf.Pets.setPreferredPet(line)
	local pref, name
	name = _G[getglobal("Glance_SBE"..gv.PetScrollIDX..line):GetName().."Text"]:GetText()
	pref = _G["Glance_SBE"..gv.PetScrollIDX..line]:GetChecked()
	if pref == 1 then
		pref = true
	else
		pref = false
	end
	if name ~= nil then
		spa.Pets[name] = pref
	end
	gf.Pets.resetPetList()
end

---------------------------
-- is summoned
---------------------------
function gf.Pets.isSummoned(id)
	if C_PetJournal.GetSummonedPetGUID() == id then
		return true
	else
		return false
	end
end

---------------------------
-- summon
---------------------------
function gf.Pets.summon(id)
	local creatureID, creatureName, creatureSpellID, icon, issummoned = GetCompanionInfo("CRITTER", id);
	if issummoned then
		DismissCompanion("CRITTER")
	else
		local petID, speciesID, isOwned, customName, level, favorite, isRevoked, name, icon, petType, creatureID, sourceText, description, isWildPet, canBattle, tradable, unique = C_PetJournal.GetPetInfoByIndex(id, false)
		C_PetJournal.SummonPetByGUID(petID)
	end

end

---------------------------
-- get pet info
---------------------------
function gf.Pets.petInfo(id)
	local petID, speciesID, isOwned, customName, level, favorite, isRevoked, name, icon, petType, creatureID, sourceText, description, isWildPet, canBattle, tradable, unique = C_PetJournal.GetPetInfoByIndex(id, false)
	if C_PetJournal.GetSummonedPetGUID() == petID then
		issummoned = true
	else
		issummoned = false
	end
	local showPet = true
	if spa.Pets[name] ~= nil then
		showPet = spa.Pets[name]
	end
	--local health, maxHealth, attack, speed, rarity = C_PetJournal.GetPetStats(petID);
	--print(rarity)
	return id, name, icon, issummoned, showPet, favorite, level, petID, petType, canBattle
end

---------------------------
-- store pets in {}
---------------------------
function gf.Pets.resetPetList()
	Glance.Debug("function","resetPetList",nil)
	wipe(ga.pet)
	local petListChanged = false
    C_PetJournal.SetFlagFilter(LE_PET_JOURNAL_FLAG_COLLECTED, true) -- displays pets we do have
    C_PetJournal.SetFlagFilter(LE_PET_JOURNAL_FLAG_NOT_COLLECTED, false) -- ignores pets we don't have
	--gv.FlagFavorites = not C_PetJournal.IsFlagFiltered(LE_PET_JOURNAL_FLAG_FAVORITES)
	--C_PetJournal.SetFlagFilter(LE_PET_JOURNAL_FLAG_FAVORITES, false) -- turn off favorites only
	gv.PetCount = C_PetJournal.GetNumPets(false)
	for i=1,gv.PetCount do
		ga.pet[i] = { gf.Pets.petInfo(i) }
		if spa.Pets[ga.pet[i][2]] == nil then
			spa.Pets[ga.pet[i][2]] = true
			petListChanged = true
		end
	end
	if petListChanged then gf.sendMSG("Your pet list has changed.") end
	--if gv.FlagFavorites then 
	--	C_PetJournal.SetFlagFilter(LE_PET_JOURNAL_FLAG_FAVORITES, true)
	--end
end

---------------------------
-- load on demand
---------------------------
if gv.loaded then
	gf.Enable("Pets")
end